==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odt/dom/TextListItemHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odt.dom;

import org.xml.sax.Attributes;
import com.openexchange.office.filter.odf.INodeAccessor;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class TextListItemHandler extends SaxContextHandler {

    final INodeAccessor elementWriterAccessor;
    final TextList textList;
    final boolean headerList;
    final Attributes attributes;
    boolean firstParagraph;

    public TextListItemHandler(SaxContextHandler parentContext, INodeAccessor elementWriterAccessor, TextList textList, boolean headerList, Attributes attributes) {
        super(parentContext);

        this.elementWriterAccessor = elementWriterAccessor;
        this.textList = textList;
        this.headerList = headerList;
        this.attributes = attributes;
        firstParagraph = true;
    }

    @Override
    public SaxContextHandler startElement(Attributes attributes, String uri, String localName, String qName) {
        final TextListItem textListItem = new TextListItem(textList, headerList, attributes);
        if(!firstParagraph) {
            textListItem.setIsHeader(true);
        }
        if(qName.equals("text:number")) {
            return new TextNumberHandler(this, textListItem);
        }
        else if(qName.equals("text:list")) {
            return new TextListHandler(this, elementWriterAccessor, textListItem.createChildList(attributes));
        }
        else if(qName.equals("text:p")) {
            firstParagraph = false;
            final Paragraph paragraph = new Paragraph(false, attributes, textListItem);
            elementWriterAccessor.getContent().add(paragraph);
            return new ParagraphHandler(this, paragraph);
        }
        else if(qName.equals("text:h")) {
            firstParagraph = false;
            final Paragraph paragraph = new Paragraph(true, attributes, textListItem);
            elementWriterAccessor.getContent().add(paragraph);
            return new ParagraphHandler(this, paragraph);
        }
        else if(qName.equals("text:soft-page-break")) {
            //
        }
        return this;
    }
}

==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odt/dom/TextListItemHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odt.dom;

import org.xml.sax.Attributes;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.INodeAccessor;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class TextListItemHandler extends SaxContextHandler {

    final INodeAccessor elementWriterAccessor;
    final TextList textList;
    final boolean headerList;
    final AttributesImpl textListAttributes;
    boolean firstParagraph;

    public TextListItemHandler(SaxContextHandler parentContext, INodeAccessor elementWriterAccessor, TextList textList, boolean headerList, Attributes attributes) {
        super(parentContext);

        this.elementWriterAccessor = elementWriterAccessor;
        this.textList = textList;
        this.headerList = headerList;
        this.textListAttributes = new AttributesImpl(attributes);
        firstParagraph = true;
    }

    @Override
    public SaxContextHandler startElement(Attributes attributes, String uri, String localName, String qName) {
        final TextListItem textListItem = new TextListItem(textList, headerList, textListAttributes);
        if(!firstParagraph) {
            textListItem.setIsHeader(true);
        }
        if(qName.equals("text:number")) {
            return new TextNumberHandler(this, textListItem);
        }
        else if(qName.equals("text:list")) {
            return new TextListHandler(this, elementWriterAccessor, textListItem.createChildList(attributes));
        }
        else if(qName.equals("text:p")) {
            firstParagraph = false;
            final Paragraph paragraph = new Paragraph(false, attributes, textListItem);
            elementWriterAccessor.getContent().add(paragraph);
            return new ParagraphHandler(this, paragraph);
        }
        else if(qName.equals("text:h")) {
            firstParagraph = false;
            final Paragraph paragraph = new Paragraph(true, attributes, textListItem);
            elementWriterAccessor.getContent().add(paragraph);
            return new ParagraphHandler(this, paragraph);
        }
        else if(qName.equals("text:soft-page-break")) {
            //
        }
        return this;
    }
}
